#
# spec file for package libwnck
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libwnck
Version:        43.2
Release:        1.3
Summary:        Window Navigator Construction Kit (Library Package)
License:        LGPL-2.1-or-later
Group:          Development/Libraries/GNOME
URL:            https://git.gnome.org/browse/libwnck
Source0:        %{name}-%{version}.tar.zst

BuildRequires:  fdupes
BuildRequires:  gettext-devel
BuildRequires:  gobject-introspection-devel
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libstartup-notification-1.0)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xres)

%description
The Window Navigator Construction Kit is a library that can be used to
write task lists, pagers, and similar GNOME programs.

%package -n libwnck-3-0
Summary:        Window Navigator Construction Kit (Library Package)
Group:          Development/Libraries/GNOME
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}
#

%description -n libwnck-3-0
The Window Navigator Construction Kit is a library that can be used to
write task lists, pagers, and similar GNOME programs.

%package -n typelib-1_0-Wnck-3_0
Summary:        Window Navigator Construction Kit (Library Package) -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-Wnck-3_0
The Window Navigator Construction Kit is a library that can be used to
write task lists, pagers, and similar GNOME programs.

This package provides the GObject Introspection bindings for libwnck.

%package tools
Summary:        Window Navigator Construction Kit -- Tools
Group:          Development/Libraries/GNOME

%description tools
The Window Navigator Construction Kit is a library that can be used to
write task lists, pagers, and similar GNOME programs.

This package provides some utilities based on libwnck.

%package devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Libraries/GNOME
Requires:       libwnck-3-0 = %{version}
Requires:       typelib-1_0-Wnck-3_0 = %{version}
Obsoletes:      libwnck-doc < %{version}
Provides:       libwnck-doc = %{version}

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-Dintrospection=enabled \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name}-3.0
%fdupes %{buildroot}/{_prefix}

%post -n libwnck-3-0 -p /sbin/ldconfig
%postun -n libwnck-3-0 -p /sbin/ldconfig

%files tools
%{_bindir}/wnck-urgency-monitor
%{_bindir}/wnckprop

%files lang -f %{name}-3.0.lang

%files -n libwnck-3-0
%license COPYING
%{_libdir}/*.so.*

%files -n typelib-1_0-Wnck-3_0
%{_libdir}/girepository-1.0/Wnck-3.0.typelib

%files devel
%doc AUTHORS README NEWS ChangeLog
%{_includedir}/libwnck-3.0/
%{_libdir}/pkgconfig/libwnck-3.0.pc
%{_libdir}/*.so
%{_datadir}/gir-1.0/Wnck-3.0.gir

%changelog
* Tue Jan 14 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.2:
  + Add WnckHandle to the docs.
  + Add missing build dependency.
  + Do not restore original event mask.
- Switch to source service for tarball/source.
* Sat Oct  5 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.1:
  + Return correct number of application windows.
  + Avoid showing pointless tooltips.
  + Do not remove underscores form window titles.
  + Do not crash if XRes 1.2 is not available.
  + Do not crash if display is not available.
- Drop handle-avoid-segfault-in-invalidate-icons.patch: Fixed
  upstream.
* Mon Aug 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire gettext-devel instead of gettext: allow OBS to
  shortcut through gettext-runtime-mini.
* Fri Dec 16 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: there is no known consumer of the -32bit
  package.
* Wed Nov  9 2022 Dude <le0nard@posteo.net>
- Add handle-avoid-segfault-in-invalidate-icons.patch to fix a
  segmentation fault (boo#1204157)
* Fri Sep 16 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + WnckHandle is now public and should be used for all the
    operations. Usage of all the older entry-point getters is now
    deprecated.
* Thu Feb 17 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.1:
  + Revert "pager: do not change workspace size from size_allocate"
  + Updated translations.
- Drop libwnck-rpmlintrc: No longer needed.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Fri May 14 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + Features:
  - Use new GNOME versioning scheme (not strictly the same
    schedule though).
  - pager: Add API to disable scrolling.
  - tasklist: Reworked the size management to use internal
    WnckButton and GTK's preferred size.
  - Add WnckHandle (private for now).
  + Fixes:
  - Do not leak pango font description.
  - tasklist: Use geometries to respect HiDPI settings.
  + Updated translations.
* Wed Mar 25 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.0:
  + Add a weak reference callback to window to disconnect obsolete
    signal handlers.
  + pager: Add scroll modes.
  + meson build fixes.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed May  1 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Add signals for enter and leave notify events in task list.
  + Meson: depend on 0.50.0, use install_dir for .pc file and
    subdir parameter.
- Drop libwnck-meson-0.50.patch: Fixed upstream.
* Wed Apr 17 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Add libwnck-meson-0.50.patch: Fix build with meson 0.50.
* Wed Feb  6 2019 bjorn.lie@gmail.com
- Fix translation-update-upstream call, needed after update of
  translation-update-upstream in distro.
* Tue Jan  8 2019 bjorn.lie@gmail.com
- Update to version 3.31.4:
  + Meson: cleanups to the dependencies and fixed docs quotes.
  + Wnckprop: force it working under x11, so that it will work in
    Wayland for X11 clients.
  + Update class group icon when window icon has changed.
* Sat Jan  5 2019 bjorn.lie@gmail.com
- Update to version 3.31.1:
  + Add support to build using meson.
- Switch to meson buildsystem, add meson BuildRequires and macros.
- Add libwnck-rpmlintrc: Filter out bogus rpmlint warning about
  libwnck-tools not containing any libs.
* Wed Sep 12 2018 antoine.belvire@opensuse.org
- Update to version 3.30.0:
  + Use single precision floats to double.
  + Allow setting the same client type (bgo#792304).
  + Remove usage of various deprecated functions and modernize
    code.
  + Add gitlab-ci pipeline (glgo#GNOME/libwnck#3).
  + Updated translations.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Jul 28 2017 zaitor@opensuse.org
- Update to version 3.24.1:
  + Fixed regression causing not working pin window.
  + Fixed Localedir.
* Sun Jul  2 2017 zaitor@opensuse.org
- Update to version 3.24.0:
  + Bump GTK+ required version to 3.22.0.
  + Various refactoring to remove deprecated code.
  + Add an option to disable the tasklist scroll event.
  + Add wrap-on-scroll option for WnckPager widget.
  + wnck-image-menu-item: fix memory leak.
  + Updated translations.
- Replace intltool with gettext BuildRequires following upstream
  changes.
* Wed Jun 29 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + selector: Don't use deprecated GtkMisc.
  + tasklist:
  - Ignore size_allocate with invalid size.
  - Queue resize on button not on its content.
  - Don't use deprecated GtkMisc.
  + test-wnck: Don't use deprecated gtk_tree_view_set_rules_hint.
  + wnckprop: Don't use deprecated gdk_cursor_new.
  + workspace-accessible:
  - Drop obsolete GTK_CHECK_VERSION.
  - Don't use deprecated atk_component_get_position.
- Add https://git.gnome.org/browse/libwnck to URL, silence rpmlint.
  libwnck does not have a wiki entry upstream, hence using the git
  ref instead.
* Tue Jun 21 2016 zaitor@opensuse.org
- Update to version 3.20.0:
  + xutils: add error trap in try_pixmap_and_mask.
  + Window: ignore unhandled non-_NET_WM actions.
  + ActionMenu: Use gtk_label_set_text_with_mnemonic instead of
    gtk_label_set_text.
  + tasklist: set css name.
  + selector: set css name.
  + pager: set css name.
  + configure.ac: redefine introspection dirs using proper
    prefixes.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
- Drop libwnck_spec-update.sh and all macros related to it from
  spec, it no longer provide any use, nor is it working as expected
  any more. Also drop an conditional for a long gone version of
  openSUSE.
* Sat Feb  6 2016 zaitor@opensuse.org
- Update to version 3.14.1:
  + WnckWindow: Add a new 'type-changed' signal.
  + Don't use deprecated style properties.
  + pager: use correct state flags.
  + selector: avoid warnings from GtkStyleContext.
  + tasklist: avoid warnings from GtkStyleContext.
  + Back to dependency on gtk+-3.0 >= 3.10.
  + Updated translations.
* Mon Nov 24 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Fixes:
  - xutils:
    . Support non-standard depths for icon pixmaps.
    . Correctly link against libXrender.
  - pager: don't return invalid workspace rect.
  - tasklist:
    . Fix missing icon in tasklist button.
    . Don't use deprecated GtkImageMenuItem.
  - window-action-menu: don't use deprecated GtkImageMenuItem.
  + Updated translations.
* Mon Sep  8 2014 dimstar@opensuse.org
- Update to version 3.4.9:
  + TaskList: remove new Startup Notification API.
- Changes from version 3.4.8:
  + Add support for _GTK_FRAME_EXTENTS.
  + Fixes:
  - WindowActionMenu: unset window and stop async events on
    dispose.
  - TaskList: use new Startup Notification API.
  + Updated translations.
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 3.4.7:
  + Add wnck_set_default_icon_size and
    wnck_set_default_mini_icon_size functions to allow clients to
    define the size of the icons to be used for windows and
    applications.
* Tue Aug  6 2013 zaitor@opensuse.org
- Update to version 3.4.6:
  + Features:
  - Add option to close windows with mouse middle click on button
    in tasklist.
  - Add API to define task list orientation.
  + Fixes:
  - ClassGroup: fix class signal signature.
  - Get rid of the deprecated code in TaskList, Selector and
    Pager.
  + Updated translations.
* Fri Feb  8 2013 dimstar@opensuse.org
- Update to version 3.4.5:
  + Features:
  - Add getter and notifier for the Window role.
  - Emit signals when a window instance or group name (WM_CLASS)
    changes.
  + Fixes:
  - Remove deprecated APIs for device grabbing.
  - Fix wnckprop hang, that made the system unusable.
  - Fix build with recent automake.
  - Use a little less power using g_timeout_add_seconds.
  + Updated translations.
* Mon Nov 12 2012 dimstar@opensuse.org
- Update to version 3.4.4:
  + Updated translations.
* Tue Sep  4 2012 dimstar@opensuse.org
- Update to version 3.4.3:
  + Add deprecation attributes to deprecated functions
  + Require gtk+-3.0 >= 3.4.0
  + Updated translations.
* Mon May 14 2012 vuntz@opensuse.org
- Update to version 3.4.2:
  + Fix mouse wheel scrolling with new GTK+.
  + Add --enable-tools to enable/disable installation of tools.
  + Updated translations.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Updated translations.
* Mon Feb 20 2012 vuntz@opensuse.org
- Add explicit pkgconfig(x11) and pkgconfig(xres) BuildRequires, to
  avoid issues after the big xorg-x11 packaging change.
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 3.3.5:
  + Features:
  - Add wnck_shutdown() API
  + Fixes:
  - Don't ask for tasklist menus to be pushed in
  + Updated translations.
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-Wnck-3_0 subpackage.
- Add typelib-1_0-Wnck-3_0 Requires to devel subpackage.
* Sun Oct 16 2011 vuntz@opensuse.org
- Update to version 3.2.1:
  + Updated translations.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Updated translations.
* Tue Sep 20 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + Fix srcdir != builddir build
  + Updated translations.
* Wed Aug 31 2011 vuntz@opensuse.org
- Update to version 3.1.90:
  + Fixes:
  - Added missing introspection annotations
  + Misc
  - Link against libm
  + Updated translations.
* Fri Aug 12 2011 dimstar@opensuse.org
- Update to version 3.1.5:
  + Features:
  - Add API to get WM_CLASS group name & instance name of a
    WnckWindow
  - Change WnckClassGroup to talk about identifier instead of
    resource class.
  + Fixes:
  - Fix tasklist taking some space when there is no window
  - Remove unused variables
  - Stop using several deprecated APIs
  - Remove disabling of libgnomeui sounds
  - Do not connect same signal handler twice
  + Misc:
  - Modernize build system
  + Updated translations.
* Tue May 24 2011 dimstar@opensuse.org
- Update to version 3.0.2:
  + Updated translations.
- Change libwnck-doc Obsoletes from <= to < to fix a rpmlint
  warning.
* Wed May  4 2011 vuntz@opensuse.org
- Fix License tag of devel subpackage to be LGPLv2.1+ instead of
  GPLv2+. Fix bnc#691447.
* Thu Apr 21 2011 vuntz@opensuse.org
- Add missing pkgconfig(libstartup-notification-1.0) BuildRequires.
- Move the small utilities to a tools subpackage, and remove the
  libwnck binary package.
- Add libwnck Provides/Obsoletes to libwnck-3-0; this will also
  help make the lang package installable.
- Change the libwnck Requires in devel package to libwnck-3-0.
* Wed Apr  6 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Updated translations.
- Changes from version 2.91.92:
  + Require GTK+ 3.0
- Changes from version 2.91.90:
  + Fixes:
  - Port widgets to GtkStyleContext
  - Improve geometry management of WnckPager
  - Add switching workspace on scroll events to WnckPager
  - Fix crash when fetching some icons
  - Make most of the code not assume the display is the
    default one
  - Code cleanups
  + Misc:
  - Add high-level documentation, with hints and examples
  - Build fixes
- Changes from version 2.91.6:
  + Major changes:
  - Port to GTK+ 3
  - Enforce single include for libwnck
  + API Changes:
  - Drop previously deprecated API:
    wnck_screen_get_workspace_index,
    wnck_screen_get_workspace_neighbor, wnck_pager_set_screen,
    wnck_tasklist_set_minimum_width,
    wnck_tasklist_get_minimum_width,
    wnck_tasklist_set_minimum_height,
    wnck_tasklist_get_minimum_height,
    wnck_tasklist_set_screen, wnck_gtk_window_set_dock_type,
    wnck_create_window_action_menu
  - Remove screen argument from
    wnck_pager_new and wnck_tasklist_new
  + Fixes:
  - Fix link errors for wnckprop
  - Start removing assumptions where default display was used
  - Add missing introspection annotation
  - Plug memory leak
  + Updated translations.
- Rename libwnck-1-22 to libwnck-3-0 after library name change.
- Change gtk2-devel BuildRequires to gtk3-devel.
- Remove explicit glib2-devel and gtk2-devel Requires in devel
  package: the right ones will be added the pkgconfig() way.
- Do not add -fno-strict-aliasing to CFLAGS anymore, it's not
  needed.
* Mon Mar 21 2011 coolo@novell.com
- licenses package is about to die
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Wed Nov 17 2010 dimstar@opensuse.org
- Update to version 2.30.6:
  + Adapt to GtkObject removal in GTK3
  + Add a small test utility to make it easy to test urgency hints
  + Updated translations.
* Wed Sep 29 2010 aj@suse.de
- Change lang package Requires to Recommends since it is not
  mandatory at runtime.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.30.5:
  + Fix pager with multiple rows, regression from 2.30.4
  + Associate .gir with pkg-config file
  + Updated translations.
* Sat Sep 18 2010 vuntz@opensuse.org
- Move gir files to devel subpackage.
* Tue Sep 14 2010 vuntz@opensuse.org
- Update to version 2.30.4:
  + Stop using gdk_display
  + Update information in README and other files
  + Updated translations.
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 2.30.3:
  + Additional GSeal-related fix
  + Fix failure to build outside source tree
  + Add introspection annotations
  + Updated translations.
* Fri Jul 16 2010 vuntz@opensuse.org
- Update to version 2.30.2:
  + Fixes:
  - Many GSeal-related fixes
  - Do not ship gir files in the tarball
  + Updated translations.
* Tue Mar 30 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + Fixes
  - Many GSeal-related fixes
  - Use a GtkMenuSeparator with a label instead of a hack for
    workspace menu items in selector
  + Updated translations.
* Mon Mar 22 2010 vuntz@opensuse.org
- Remove manual check for the package name to follow the library
  policy: rpmlint does this now.
* Sun Mar 21 2010 dimstar@opensuse.org
- Add BuildRequires gobject-introspection-devel.
* Tue Mar  9 2010 dimstar@opensuse.org
- Update to version 2.29.92:
  +  Feature:
  - Integrate gobject-introspection support
  + Fixes:
  - Build with latest GSeal'ed GTK+ (Vincent)
  - Do not lose the pinned status when dragging a window in a
    tasklist
  - Use _NET_WM_WINDOW_TYPE_SPLASH instead of non-existing
    _NET_WM_WINDOW_TYPE_SPLASHSCREEN (Vincent)
  + Misc:
  - Small documentation improvement for
    wnck_window_move_to_workspace() to specify what happens to
    pinned windows
  - Fix build when building out of source tree
  + Updated translations.
* Mon Feb 22 2010 vuntz@opensuse.org
- Update to version 2.29.91:
  + Use single-include for atk
  + Updated translations.
* Wed Jan 27 2010 vuntz@opensuse.org
- Update to version 2.29.6:
  + Fix generation of wnck-enum-types.c to not break bindings
  + Modernize a bit the build system
  + Updated translations.
- Drop libwnck-fix-bindings.patch: fixed upstream.
- Remove en@shaw translation on openSUSE 11.2 and earlier.
* Tue Jan  5 2010 jengelh@medozas.de
- Package baselibs.conf
* Tue Oct  6 2009 vuntz@opensuse.org
- Add libwnck-fix-bindings.patch to fix an issue that broke python
  bindings for libwnck.
* Tue Sep 22 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Updated translations.
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 2.27.92:
  + Always show icons in tasklist group menu
  + Make startup-notification non-automagic
  + Updated translations.
* Wed Jul 29 2009 vuntz@novell.com
- Update to version 2.27.5:
  + New wnck-urgency-monitor utility to monitor windows with urgent
  hint
* Sun Jul 19 2009 vuntz@novell.com
- Update to version 2.27.4:
  + Fix wnck_application_get_icon_is_fallback() to actually work
  + Fix gtk-doc warning
  + Code cleanup
  + Always show icons in selector menu
  + Use shave to improve build log readability
  + Build system tweaks
  + Updates translations.
* Mon May 18 2009 vuntz@novell.com
- Do not make libwnck-1-22 depend on libwnck, but just on
  libwnck-lang.
* Tue Apr 14 2009 vuntz@novell.com
- Update to version 2.26.1:
  + Updated translations.
* Tue Mar 17 2009 mboman@suse.de
- Update to version 2.26.0:
  + Translation updates
* Wed Feb 18 2009 mboman@suse.de
- Add back licenses to BuildRequires
- Fix Obsoletes/Provides
* Tue Feb 17 2009 mboman@suse.de
- Update to version 2.25.91:
  + Requires glib 2.16.0
  + Translation updates
- Merge -doc into -devel as it only contains gtk-doc
- Remove gnome-common, perl-XML-Parser, update-desktop-files and
  licenses from BuildRequires
* Sun Feb  1 2009 mboman@suse.de
- Update to version 2.25.5:
  + Make libwnck compile with gnome-common DEPRECATED variables
  + Use C_() instead of Q_()
  + Translation updates
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Sat Dec 20 2008 mboman@suse.de
- Update to version 2.25.3:
  + Use single include for GTK+
  + Fix compiler warning
* Sat Dec 13 2008 mboman@suse.de
- Update to version 2.24.2:
  + Translation updates
* Thu Oct 23 2008 maw@suse.de
- Update to version 2.24.1:
  + Updated translations.
* Tue Sep 23 2008 mboman@suse.de
- Update to version 2.24.0:
  + Translation updates.
* Wed Sep 10 2008 maw@suse.de
- Update to version 2.23.92:
  + Updated translations.
* Mon Sep  1 2008 mboman@novell.com
- Update to version 2.23.91:
  + Update the default window icon
  + Update translations
* Thu Aug 28 2008 maw@suse.de
- Don't package static libraries or libtool archives.
* Wed Aug  6 2008 maw@suse.de
- Update to version 2.23.6:
  + Updated translations.
* Wed Jun 18 2008 maw@suse.de
- Update to version 2.23.4:
  + Fix a bug where, when the last window disappears, libwnck
    internals aren't updated and you still have a window in the
    window list
  + Updated translations.
* Wed May 21 2008 cthiel@suse.de
- fix baselibs.conf
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Apr  9 2008 maw@suse.de
- Update to version 2.22.1:
  + Bugs fixed: bgo#517750, bgo#520124, bgo#520704, bgo#520726
  + Updated translations.
* Mon Mar 17 2008 vuntz@suse.de
- After a discussion with David Raveman, we agree that the last
  three patches (libwnck-2.12.2-window-move-1.patch,
  libwnck-opacity-2.patch, libwnck-border_width-fix-2.patch) are
  not needed for compiz any more, so killing them.
* Mon Mar 17 2008 vuntz@suse.de
- Remove libwnck-realistic-layout.patch.
  Was fixed upstream in June 2007, see bgo#339861.
* Fri Mar 14 2008 maw@suse.de
- Update to version 2.22.0:
  + Fix wnck_window_set_geometry() to work as intended, ie
    including decorations (bgo#518606)
  + Updated translations.
* Tue Mar  4 2008 maw@suse.de
- Update to version 2.21.92:
  + Fix wnck_window_set_geometry() not working without a main loop
  + Updated translations.
* Tue Feb 19 2008 maw@suse.de
- Update to version 2.21.91:
  + Updated translations.
* Tue Jan 29 2008 rodrigo@suse.de
- Update to version 2.21.90:
  * Fix pager to correctly work in multiscreen environment
- Added missing glib2-devel to -devel package Requires
* Thu Nov 15 2007 jpr@suse.de
- Remove libwnck-viewport-2.patch, it was obsoleted by a different
  upstream patch
* Tue Sep 18 2007 sbrabec@suse.cz
- Update to version 2.20.0:
  * translations update
* Mon Sep 10 2007 mauro@suse.de
- Update to version 2.19.92:
  + Add translator comments for wnckprop (Andre Klapper) [#468320]
* Thu Aug 30 2007 maw@suse.de
- Update to version 2.19.90:
  + Remove weak pointers on fields in task structure before
    freeing task block (bugzilla.gnome.org 139080)
  + Updated translations.
* Wed Aug  8 2007 maw@suse.de
- Split off a -lang subpackage.
* Wed Aug  1 2007 maw@suse.de
- Update to version 2.19.6:
  Fixes
  - Make the window action menu work with viewport (Vincent) [#352383]
  - Correctly draw workspaces with viewport in the pager (Vincent)
  - Fix typo in a string of wnckprop (Theppitak Karoonboonyanan)
* Fri Jul 27 2007 sbrabec@suse.cz
- Fixed typo in shared library name.
* Tue Jul 17 2007 sbrabec@suse.cz
- Fixed shared library packaging.
- Added script to update library package names.
* Sat Jul 14 2007 mrueckert@suse.de
- fixed typo in previous change
* Sat Jul 14 2007 mrueckert@suse.de
- use libwnck-devel and libwnck-doc. the file content would conflict
  anyway so there is no need to have them as versioned subpackages.
* Mon Jul  9 2007 maw@suse.de
- Following up on the package rename, add some new
  Provides/Obsoletes.
* Fri Jul  6 2007 maw@suse.de
- Update to version 2.19.4, and rename to libwnck-1-22 to match
  sonames.
- Remove upstreamed libwnck-216129-tasklist-crash.patch
* Tue May 29 2007 danw@suse.de
- Add libwnck-216129-tasklist-crash.patch from upstream to fix a
  panel crash. #216129
* Fri Mar 23 2007 maw@suse.de
- Update to version 2.18.0
- Minor changes:
  * libwnck/tasklist.c: (wnck_tasklist_scroll_cb): fix left/right
    scroll for RTL
  * libwnck/pager.c: (wnck_update_drag_icon): improve a bit, so
    that the icon has a good width/height ratio, and is not always
    huge
  * libwnck/pager.c: (wnck_pager_set_n_rows): don't accept to set to
    less than 1 row. Again. (My one-line patch was broken ;-))
  * test-tasklist.c: add an option to always group windows, and default
    to automatic grouping
  * test-tasklist.c: (main):
  * test-selector.c: (main): don't use gtk_window_set_policy(), but
    gtk_window_set_resizable()
  * libwnck/pager.c: (wnck_pager_set_n_rows): don't accept to set to
    less than 1 row
* Mon Feb 19 2007 maw@suse.de
- Update to version 2.17.91
* Wed Feb  7 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552).
* Wed Dec 13 2006 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Tue Nov  7 2006 dreveman@suse.de
- Fix viewport patch so it doesn't crash when creating action menu
  for windows that are visible on more than one workspace. #217262
* Wed Oct 18 2006 sbrabec@suse.cz
- Enabled creating of doc package (#193240).
* Mon Oct 16 2006 dreveman@suse.de
- Fix broken border width patch. 178222.
- Remove ibwnck-2.12.2-virtual-aspect-1.patch, it's no longer
  needed.
* Tue Oct  3 2006 jhargadon@suse.de
- update to version 2.16.1
- Fix critical warning and leak
- Avoid sending spurious icon geometry updates
- Require GTK+ 2.8.0
- translation updates
* Thu Sep 14 2006 jhargadon@suse.de
- update to version 2.16.0
- translation updates
* Thu Aug 31 2006 jhargadon@suse.de
- update to version 2.15.92
- Fix crash when tasklist is destroyed
- Update delete icon for the context menu
- translation updates
* Tue Aug 15 2006 jhargadon@suse.de
- update to version 2.15.91
- Changed the glowing code to have less and saner style properties
* Fri Aug  4 2006 gekker@suse.de
- Update to version 2.15.90
- Remove upstreamed patches
  Features
  - Add move/resize window API (Magnus Therning)
  - Improve glowing effect in tasklist and make it themeable (Benjamin Berg)
    [#325176]
  - Use cairo in the pager (Benjamin Otte) [#339293]
  - Improve drag and drop in the pager (Nickolay V. Shmyrev, Benjamin Otte)
    [#96675, #339293]
  - Improve look of the pager (Benjamin Otte) [#339293]
  - Add dragging of windows from the tasklist (Nickolay V. Shmyrev) [#96675]
  - Sort window in a group alphabetically (Xavier Claessens, Vincent)
  - Change active window when scrolling on the selector (Nigel Tao)
  - Add scrolling support to the tasklist (Xavier Claessens)
  Fixes
  - Correctly set relief for group buttons in the tasklist (Benjamin Otte)
  - Make windows that go to the bottom occupy the last pixel of the pager
    (Benjamin Otte)
  - Fix crashes
  - Don't change workspace when releasing the button on another workspace
    (Vincent) [#110510]
  - Fix leaks (Dan Winship) [#334137]
  - Fix minimization of "always on visible desktop" windows with the tasklist
    (Vincent) [#335316]
  - Fix transient cycles causing infinite loops (Dan Winship, Elijah) [#332493]
  - Immediately show notification for demands-attent/urgent windows on other
    workspaces in the tasklist (Leszek Matok) [#336142]
  - Don't minimize the window when it's on another desktop and it was the last
    active window (Vincent) [#331661]
  - Fix C89 compliance (Jens Granseuer) [#332866]
  - Fix window disappearing in workspace switcher after drag and drop (Vincent)
    [#317373]
  - Fix corrupted drawing of windows (Vincent) [#155502]
  - Include demands-attention/urgent windows unconditionally in
    tasklist; this should help users not miss important windows on
    other workspaces (Elijah) [#305979]
  - Synchronize the right-click-menu with that of Metacity's (Srirama
    Sharma, Leena Gunda, Christian Neumair) [#135710]
  - Escape window titles used in pango markup, avoids some crashes too
    (Vincent Noel, jylefort FreeBSD org) [#306289]
  - Correctly catch and handle demands-attention/urgent state changes
    for transients of windows in the tasklist (Elijah) [#317541]
  - Make the pager Fitts's law compliant when shadow type is none
    (Vincent) [#304248]
  - Correctly specify the source indication (Elijah)
  - Use virtual desktop size when computing size of pager (Loic Minier, Vincent)
  Update Translations
* Tue May 30 2006 danw@suse.de
- Patch in a new method from libwnck HEAD to allow compiz to know
  when a window has a real name (as opposed to a fallback name like
  "untitled window"). #173059
* Fri May 12 2006 dreveman@suse.de
- Fix so that correct geometry is returned when border width is
  greater than 0. (bnc 178222)
* Thu May  4 2006 dreveman@suse.de
- Add opacity window action sub-menu patch.
  (libwnck-opacity-2.patch)
- Add patch for viewport options in window action menu.
  (libwnck-2.12.2-viewport-1.patch) (bnc 160004)
* Wed Apr 26 2006 joeshaw@suse.de
- Add a patch to fix some layout and grouping bugs in the tasklist.
  (bnc #148840)
* Tue Mar  7 2006 danw@suse.de
- Fix a crash in libwnck-2.12.2-virtual-aspect-1.patch (144722).
  Fix some memory leaks to hopefully fix 78329.
* Tue Feb 28 2006 danw@suse.de
- Fix infinite loop when a window is marked TRANSIENT_FOR itself
  (116722)
* Wed Feb 15 2006 gekker@suse.de
- Fix crash on window switch (b.g.o#327435)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan  7 2006 dreveman@suse.de
- Add window movement patch
* Wed Jan  4 2006 dreveman@suse.de
- Add virtual desktop aspect ratio patch
* Wed Nov 30 2005 gekker@suse.de
- Update to version 2.12.2
* Thu Oct 13 2005 gekker@suse.de
- Update to version 2.12.1
* Mon Sep  5 2005 mmj@suse.de
- Update to version 2.12.0 (GNOME 2.12)
* Mon Aug 22 2005 rodrigo@suse.de
- Update to version 2.11.92
* Thu Aug 11 2005 gekker@suse.de
- Update to version 2.11.91
- Fix use of unitialized variable
* Fri Jul 22 2005 gekker@suse.de
- Update to version 2.11.4
* Wed Jun 22 2005 gekker@suse.de
- Update to version 2.11.3
* Wed Jun  1 2005 sbrabec@suse.cz
- Fixed devel requirements.
* Wed Mar  9 2005 gekker@suse.de
- Update to version 2.10.0 (GNOME 2.10).
* Thu Mar  3 2005 gekker@suse.de
- Update to version 2.9.92.1
* Fri Feb 11 2005 gekker@suse.de
- Update to version 2.9.91
* Sun Feb  6 2005 gekker@suse.de
- Update to version 2.9.90
* Tue Jan  4 2005 gekker@suse.de
- Update to version 2.9.3
* Mon Dec 20 2004 gekker@suse.de
- Update to version 2.8.1.
- Add gtk-doc to needed for build, release version now requires it
- Add --disable-html-dir to keep html docs from being built
* Tue Nov 23 2004 ro@suse.de
- do not use libXRes on 9.0-x86_64
* Fri Nov 19 2004 ro@suse.de
- removed extra aclocal include directive
* Mon Oct 25 2004 ro@suse.de
- locale rename: no -> nb
* Thu Apr 15 2004 sbrabec@suse.cz
- Updated to version 2.6.0.1 (GNOME 2.6).
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr and %%run_ldconfig
* Tue Oct  7 2003 sbrabec@suse.cz
- Updated to version 2.4.0.1 (GNOME 2.4).
* Tue Jul 15 2003 pthomas@suse.de
- Clean up the code, specially where dereferencing type-punned
  pointers would break alias analysis.
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Tue Jun 24 2003 sbrabec@suse.cz
- Updated to version 2.2.2.
- Use %%find_lang.
* Sun Jun  1 2003 ro@suse.de
- add translations to filelist
* Wed Jan 29 2003 hhetter@suse.de
- update to version 2.2.0
* Thu Jan 16 2003 hhetter@suse.de
- updated to version 2.1.90
- use gtk2-devel-packages in #neededforbuild
* Wed Jan 15 2003 sbrabec@suse.cz
- Added expat to neededforbuild.
* Thu Nov 28 2002 hhetter@suse.de
- updated to version 0.18 [GNOME 2.0.3]
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xf86 xdevel> to <x-devel-packages>
* Thu Oct 24 2002 hhetter@suse.de
- use "-c" with automake (Bug Id #21066)
* Fri Aug  9 2002 hhetter@suse.de
- updated to version 0.16
* Wed Jun 19 2002 ro@suse.de
- use "-a -f" for automake
* Wed Jun 19 2002 hhetter@suse.de
- updated to version 0.14
* Tue Jun  4 2002 hhetter@suse.de
- updated to version 0.13, sorce frozen
* Tue May 14 2002 ro@suse.de
- use libdir
* Wed Apr 10 2002 hhetter@suse.de
- updated to version 0.7
* Thu Jan 17 2002 hhetter@suse.de
- really prefixed to /opt/gnome2
* Thu Jan 17 2002 hhetter@suse.de
- prefixed to /opt/gnome2
* Wed Jan 16 2002 hhetter@suse.de
- updated to version 0.2
* Tue Jan 15 2002 hhetter@suse.de
- fixed prefix
* Mon Jan 14 2002 hhetter@suse.de
- initial SuSE package for GNOME 2.0 platform
- build with automake 1.5
